from setuptools import setup, find_packages


setup(
    name='AtlonaControl',
    version='0.8',
    license='MIT',
    author="sdoDevelop",
    author_email='sdoconnell92@gmail.com',
    packages=find_packages('AtlonaControl'),
    package_dir={'': 'AtlonaControl'},
    url='https://github.com/sdoDevelop/AtlonaControl',
    keywords='atlona',
    install_requires=[],
)
